<?php
/*
 - Author : GoldenSource.iR 
 - Module Designed For : novinopay.com
 - Mail : Mail@GoldenSource.ir
*/

use WHMCS\Database\Capsule;

if (isset($_REQUEST['invoiceId']) && is_numeric($_REQUEST['invoiceId'])) {
    require_once __DIR__ . '/../../init.php';
    require_once __DIR__ . '/../../includes/gatewayfunctions.php';
    require_once __DIR__ . '/../../includes/invoicefunctions.php';
    $gatewayParams = getGatewayVariables('novinopay');
    if (isset($_GET['PaymentStatus'])) {
        $invoice = Capsule::table('tblinvoices')->where('id', $_GET['invoiceId'])->where('status', 'Unpaid')->first();
        if (!$invoice) {
            die("Invoice not found");
        }

        $Authority = (isset($_REQUEST["Authority"]) && !empty($_REQUEST["Authority"])) ? $_REQUEST["Authority"] : "";
        $InvoiceID = (isset($_REQUEST["InvoiceID"]) && !empty($_REQUEST["InvoiceID"])) ? $_REQUEST["InvoiceID"] : "";

        if ($_GET['PaymentStatus'] == 'OK') {
            $amount = ceil($invoice->total * ($gatewayParams['currencyType'] == 'IRR' ? 1 : 10));
            if ($gatewayParams['feeFromClient'] == 'on') {
                $amount = ceil(1.01 * $amount);
            }
            $result = post_to_novinopay('verification', [
                "merchant_id" => $gatewayParams['MerchantID'],
                "amount" => (int)$amount,
                "authority" => $Authority
            ]);
            if ($result->status == 100 && $result->data->amount == $amount) {
                logTransaction($gatewayParams['name'], $_REQUEST, 'Success');
                addInvoicePayment(
                    $invoice->id,
                    $result->data->ref_id,
                    $invoice->total,
                    0,
                    'novinopay'
                );
            } else {
                logTransaction($gatewayParams['name'], array(
                    'Code' => 'novinopay Result Code',
                    'Message' => $result->status,
                    'Transaction' => $InvoiceID,
                    'Invoice' => $invoice->id,
                    'Amount' => $invoice->total,
                ), 'Failure');
            }
        }
        header('Location: ' . $gatewayParams['systemurl'] . '/viewinvoice.php?id=' . $invoice->id);
    }
    else if (isset($_SESSION['uid'])) {
        $invoice = Capsule::table('tblinvoices')->where('id', $_REQUEST['invoiceId'])->where('status', 'Unpaid')->where('userid', $_SESSION['uid'])->first();
        if (!$invoice) {
            die("Invoice not found");
        }
        $client = Capsule::table('tblclients')->where('id', $_SESSION['uid'])->first();
        $amount = ceil($invoice->total * ($gatewayParams['currencyType'] == 'IRR' ? 1 : 10));
        if ($gatewayParams['feeFromClient'] == 'on') {
            $amount = ceil(1.01 * $amount);
        }


        $data = [
            "merchant_id" => $gatewayParams['MerchantID'],
            "amount" => $amount,
            "invoice_id" => "{$invoice->id}",
            "description" => sprintf('پرداخت فاکتور #%s', $invoice->id),
            "mobile" => "{$client->phonenumber}",
            "callback_url" => $gatewayParams['systemurl'] . '/modules/gateways/novinopay.php?invoiceId=' . $invoice->id . '&callback=1',
        ];


        $result = post_to_novinopay('request', $data);
        if ($result->status == 100) {
            header('Location: ' . $result->data->payment_url);
        } else {
            echo 'اتصال به درگاه امکان پذیر نیست: ', $result->status;
        }
    }
    return;
}

if (!defined('WHMCS')) {
    die('This file cannot be accessed directly');
}

function post_to_novinopay($url, $data = false)
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, "https://api.novinopay.com/payment/ipg/v2/" . $url);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array('Content-Type:application/json; charset=utf-8'));
    curl_setopt($ch, CURLOPT_POST, 1);
    if ($data) {
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
    }
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
    $result = curl_exec($ch);
    curl_close($ch);
    return !empty($result) ? json_decode($result) : false;
}

function novinopay_MetaData()
{
    return array(
        'DisplayName' => 'ماژول پرداخت نوینو',
        'APIVersion' => '2.0',
    );
}

function novinopay_config()
{
    return array(
        'FriendlyName' => array(
            'Type' => 'System',
            'Value' => 'نوینو',
        ),
        'currencyType' => array(
            'FriendlyName' => 'نوع ارز',
            'Type' => 'dropdown',
            'Options' => array(
                'IRR' => 'ریال',
                'IRT' => 'تومان',
            ),
        ),
        'MerchantID' => array(
            'FriendlyName' => 'کد درگاه (مرچنت)',
            'Type' => 'text',
            'Size' => '255',
            'Default' => '',
            'Description' => 'مرچنت کد دریافت شده از پنل کاربری نوینو',
        ),
        'feeFromClient' => array(
            'FriendlyName' => 'دریافت مالیات از کاربر',
            'Type' => 'yesno',
            'Description' => 'برای دریافت مالیات از کاربر تیک بزنید',
        ),
    );
}

function novinopay_link($params)
{
    $htmlOutput = '<form method="GET" action="modules/gateways/novinopay.php">';
    $htmlOutput .= '<input type="hidden" name="invoiceId" value="' . $params['invoiceid'] . '">';
    $htmlOutput .= '<input type="submit" value="' . $params['langpaynow'] . '" />';
    $htmlOutput .= '</form>';
    return $htmlOutput;
}
